#
# spec file for package pijul
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pijul
Version:        1.0.0~beta.6
Release:        1.1
Summary:        Distributed version control system based on a theory of patches
License:        GPL-2.0-only
Group:          Development/Tools/Version Control
URL:            https://pijul.org/
# Fetched from https://crates.io/api/v1/crates/pijul/1.0.0-beta.6/download#/pijul-1.0.0-beta.6.tar.gz
# and renamed to get rid of the second dash.
Source0:        pijul-1.0.0~beta.6.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  cargo
BuildRequires:  clang-devel
BuildRequires:  libzstd-devel-static
BuildRequires:  pkgconfig
BuildRequires:  rust
BuildRequires:  rust-std
BuildRequires:  xxhash-devel
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(openssl)
Conflicts:      pijul-bash-completion
Conflicts:      pijul-fish-completion
Conflicts:      pijul-zsh-completion

%description
Pijul is a distributed version control system. Its distinctive feature is to be
based on a theory of patches, which makes it really distributed.

%prep
%setup -qa1
mkdir cargo-home
cat >cargo-home/config <<EOF

[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
# bypass error https://bugzilla.opensuse.org/show_bug.cgi?id=1175502
# to avoid cargo reported error if config.sub has been changed
# by build macro.
%ifarch aarch64
subname='libsodium/build-aux/config.sub'
cfgsub="./vendor/libsodium-sys/$subname"
chkjson='./vendor/libsodium-sys/.cargo-checksum.json'
if [ -f "$cfgsub" ] && [ -f "$chkjson" ]; then
  chksum=`sha256sum $cfgsub |sed -e 's/ .*//'`
  grep -q $subname $chkjson && grep -q $chksum $chkjson || sed -i -e "s#\($subname.:.\)[0-9a-f]*#\1$chksum#" $chkjson
fi
%endif

export CARGO_HOME=`pwd`/cargo-home/
cargo build --release %{?_smp_mflags} --features git

%install

install -Dm0755 target/release/pijul %{buildroot}%{_bindir}/pijul

%files
%{_bindir}/pijul

%changelog
* Mon Sep  4 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.6.
* Thu Jun  1 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.5.
- This version uses hyper 0.14.26 and h2 0.3.19, preventing CVE-2023-26964
  (bsc#1210361).
* Tue Mar  7 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.4.
- This version uses hyper 0.14.24, which prevents CVE-2022-31394
  (bsc#1208559).
* Mon May  9 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta.2:
  * Improve "pijul key" documentation.
  * "pijul pull" does not open $EDITOR anymore when given a list
    of changes.
  * Fix a bug with name conflicts.
  * Fix a few panic/unwraps problems.
  * Fix a bug where a zombile file could be deleted by
    "pijul unrecord" but its contents would stay zombie.
  * Update regex dependency to prevent CVE-2022-24713
    (bsc#1196972).
- Changes from version 1.0.0-beta.1:
  * Fixed a failed assertion in the patch text format.
  * Fixed a "merged vertices" bug when moving and editing them in
    the same patch.
* Tue Jan 25 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-beta:
  * Add --force to "add" to include ignored files.
  * Fix conflict identifiers.
  * Remove the --tag option from "push/pull".
  * Fix "log" filters.
- Changes from version 1.0.0-alpha.57:
  * Add support for tags.
  * Fix path crashes related to the non-null roots.
  * Prioritise moving a file over undeletion.
  * Show the correct paths in recursive file deletions.
  * Add --force to "reset/switch" to ignore name conflicts.
  * Avoid printing multiple names conflicts more than once.
  * Better error message when pushing to a non-existent local
    channel.
  * Fix log --filters, along with performance improvements.
* Tue Dec 21 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.56:
  * Re-implement change printing and parsing.
  * Add a root inode (initial support for submodules).
  * Fix a deprecation warning in ed25519-dalek.
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Sun Oct 24 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.55:
  * Better estimation of the maximum number of open patches that
    Pijul can keep.
  * Proper escaping of UTF-8 filenames in the patch text format.
  * Add patch filtering to "git log".
  * Add JSON output for "git log".
  * "pijul init" does not modify already existing .ignore files.
  * Improve detection of binary files.
* Tue Sep 28 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.54:
  * Improve push/pull reporting.
  * Fix a panic when outputting zombie folders.
  * Better computation of progress bars width.
  * Pushing/pulling from/to Nest discussions again.
  * Allow remotes to have different push and pull addresses.
  * Correct reporting of permission errors on external subcommands.
  * Add a .ignore file when initializing a repository containing a
    list of commonly ignored entries. See the "--kind" flag
    of the "pijul init" subcommand.
- Changes from version 1.0.0-alpha.53:
  * Fix newline issues with OpenSSH which caused clone via SSH
    to hang.
  * Do not remove untracked files when outputting.
  * Make recursive directory remove optional.
  * Add an option to limit the output size of "pijul log".
  * Make "pijul diff --short" more informative.
  * Fix "pijul diff --untracked".
  * Use the change time in addition to the modified time when
    detecting untouched files.
  * Print modifications only once in "pijul diff".
  * Do not compute the entire diff if only "--json --untracked"
    is wanted.
  * Unrecord the pending patch when pulling, in the special
    case that there is no thing to download.
  * Add a progress bar to "git push".
  * Fix "addition error" on "pijul git".
  * Better "pijul git" error message when recording.
* Tue Jul 20 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.52.
* Wed Mar 31 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.48.
* Tue Feb 16 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.38.
* Thu Jan 21 2021 Jan Engelhardt <jengelh@inai.de>
- Avoid bashisms in build recipe.
* Wed Jan 20 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.36.
* Tue Dec 22 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.24.
* Tue Dec  8 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.21.
- Enable 'Git' support (allow to import a Git repository into
  a Pijul one).
* Sun Dec  6 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.17.
* Fri Dec  4 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream version 1.0.0-alpha.15.
* Thu Aug 20 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Avoid build error for ppc64le as reported by boo#1175502
* Wed Sep  4 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update to upstream release 0.12.2.
- Add completion support for Bash, Zsh and Fish shells.
- Remove the README.md file because it is not included in the
  tarball anymore.
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias and metadata redundancies from descriptions.
- Remove duplicate %%setup call.
* Thu Aug 22 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 0.12.0.
